Documentation
¶
Index ¶
- func Assert(condition bool, msg string, v ...any)
- func DisableVerifications() func()
- func EnableAllVerifications() func()
- func EnableVerifications(verification VerificationType) func()
- func IsVerificationEnabled(verification VerificationType) bool
- func Verify(msg string, f VerifyFunc)
- type VerificationType
- type VerifyFunc
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DisableVerifications ¶
func DisableVerifications() func()
DisableVerifications unsets `envVerify` and returns a function that can be used to bring the original settings.
func EnableAllVerifications ¶
func EnableAllVerifications() func()
EnableAllVerifications enables verification and returns a function that can be used to bring the original settings.
func EnableVerifications ¶
func EnableVerifications(verification VerificationType) func()
EnableVerifications sets `envVerify` and returns a function that can be used to bring the original settings.
func IsVerificationEnabled ¶
func IsVerificationEnabled(verification VerificationType) bool
func Verify ¶
func Verify(msg string, f VerifyFunc)
Verify performs verification if the assertions are enabled. In the default setup running in tests and skipped in the production code.
Types ¶
type VerificationType ¶
type VerificationType string
type VerifyFunc ¶ added in v3.7.0
Click to show internal directories.
Click to hide internal directories.